@@ -7,7 +7,7 @@ Attean::API::Iterator - Typed iterator
 
 =head1 VERSION
 
-This document describes Attean::API::Iterator version 0.026
+This document describes Attean::API::Iterator version 0.027
 
 =head1 DESCRIPTION
 
@@ -94,7 +94,7 @@ elements from the referent.
 
 =cut
 
-package Attean::API::Iterator 0.026 {
+package Attean::API::Iterator 0.027 {
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str Object InstanceOf);
 	use Carp qw(confess);
@@ -276,7 +276,20 @@ Print each item as it is consumed (with the string generated by C<< as_string >>
 	}
 }
 
-package Attean::API::RepeatableIterator 0.026 {
+package Attean::API::StringyItemIterator 0.027 {
+	use Moo::Role;
+	sub uniq {
+		my $self	= shift;
+		
+		my %seen;
+		return $self->grep(sub {
+			my $r	= shift;
+			return not($seen{ $r->as_string }++);
+		});
+	}
+}
+
+package Attean::API::RepeatableIterator 0.027 {
 	use Moo::Role;
 	requires 'reset';
 	
@@ -312,10 +325,12 @@ package Attean::API::CanonicalizingBindingIterator {
 	}
 }
 
-package Attean::API::ResultOrTermIterator 0.026 {
+package Attean::API::ResultOrTermIterator 0.027 {
 	use Moo::Role;
 	use Types::Standard qw(ArrayRef Str);
 	has 'variables' => (is => 'rw', isa => ArrayRef[Str], default => sub { [] });
+	with 'Attean::API::StringyItemIterator';
+	
 	sub canonicalize {
 		my $self	= shift;
 		my $mapper	= Attean::TermMap->canonicalization_map;
@@ -350,9 +365,10 @@ package Attean::API::ResultOrTermIterator 0.026 {
 	};
 }
 
-package Attean::API::StatementIterator 0.026 {
+package Attean::API::StatementIterator 0.027 {
 	use Moo::Role;
 	use Scalar::Util qw(blessed);
+	with 'Attean::API::StringyItemIterator';
 	requires 'variables';
 
 	sub matching_pattern {
@@ -385,7 +401,7 @@ package Attean::API::StatementIterator 0.026 {
 	}
 }
 
-package Attean::API::TripleIterator 0.026 {
+package Attean::API::TripleIterator 0.027 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
 	with 'Attean::API::StatementIterator';
@@ -401,7 +417,7 @@ package Attean::API::TripleIterator 0.026 {
 	}
 }
 
-package Attean::API::QuadIterator 0.026 {
+package Attean::API::QuadIterator 0.027 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
 	with 'Attean::API::StatementIterator';
@@ -411,9 +427,10 @@ package Attean::API::QuadIterator 0.026 {
 	}
 }
 
-package Attean::API::MixedStatementIterator 0.026 {
+package Attean::API::MixedStatementIterator 0.027 {
 	use Moo::Role;
 	with 'Attean::API::CanonicalizingBindingIterator';
+	with 'Attean::API::StringyItemIterator';
 	sub as_quads {
 		my $self	= shift;
 		my $graph	= shift;
@@ -424,12 +441,12 @@ package Attean::API::MixedStatementIterator 0.026 {
 	}
 }
 
-package Attean::API::ResultIterator 0.026 {
+package Attean::API::ResultIterator 0.027 {
 	use Types::Standard qw(Str ArrayRef);
-
 	use Moo::Role;
 	
 	with 'Attean::API::CanonicalizingBindingIterator';
+	with 'Attean::API::StringyItemIterator';
 	has 'variables' => (is => 'rw', isa => ArrayRef[Str], required => 1);
 	sub join {
 		my $self	= shift;
@@ -449,7 +466,7 @@ package Attean::API::ResultIterator 0.026 {
 	}
 }
 
-package Attean::API::TermIterator 0.026 {
+package Attean::API::TermIterator 0.027 {
 	use Moo::Role;
 	sub canonicalize {
 		my $self	= shift;
@@ -457,6 +474,7 @@ package Attean::API::TermIterator 0.026 {
 		return $self->map( $mapper );
 	}
 	with 'Attean::API::CanonicalizingBindingIterator';
+	with 'Attean::API::StringyItemIterator';
 }
 
 1;
@@ -465,6 +483,27 @@ __END__
 
 =back
 
+=head2 Methods on Roles Supporting Stringification
+
+For iterators over roles that provide an C<as_string> method, extra methods
+are provided. These iterators are:
+
+Attean::API::ResultOrTermIterator
+Attean::API::StatementIterator
+Attean::API::MixedStatementIterator
+Attean::API::ResultIterator
+Attean::API::TermIterator
+
+They provide the following methods:
+
+=over 4
+
+=item C<< uniq >>
+
+Returns a new iterator providing unique results (based on the stringified value of the underlying elements).
+
+=back
+
 =head1 BUGS
 
 Please report any bugs or feature requests to through the GitHub web interface
